@@ -19,10 +19,10 @@
 #include <NetworkManagerQt/Manager>
 
 #if WITH_MODEMMANAGER_SUPPORT
-#include <ModemManagerQt/manager.h>
-#include <ModemManagerQt/modem3gpp.h>
-#include <ModemManagerQt/modemcdma.h>
-#include <ModemManagerQt/modemdevice.h>
+#include <ModemManagerQt/Manager>
+#include <ModemManagerQt/Modem3Gpp>
+#include <ModemManagerQt/ModemCdma>
+#include <ModemManagerQt/ModemDevice>
 #endif
 
 // Qt
@@ -450,6 +450,11 @@ QString UiUtils::wirelessBandToString(NetworkManager::WirelessSetting::Frequency
     return {};
 }
 
+QString UiUtils::wirelessFrequencyToString(uint frequency)
+{
+    return i18nc("Wireless connection frequency", "%1 GHz", frequency / 1000.0);
+}
+
 #if WITH_MODEMMANAGER_SUPPORT
 QString UiUtils::convertAllowedModeToString(ModemManager::Modem::ModemModes modes)
 {
