@@ -99,7 +99,7 @@ void IpV6RoutesWidget::setRoutes(const QList<NetworkManager::IpRoute> &list)
 {
     d->model.removeRows(0, d->model.rowCount());
     for (const NetworkManager::IpRoute &route : list) {
-        QList<QStandardItem *> item{
+        const QList<QStandardItem *> item{
             new QStandardItem(route.ip().toString()),
             new QStandardItem(QString::number(route.prefixLength(), 10)),
             new QStandardItem(route.nextHop().toString()),
@@ -140,7 +140,7 @@ QList<NetworkManager::IpRoute> IpV6RoutesWidget::routes() const
 
 void IpV6RoutesWidget::addRoute()
 {
-    QList<QStandardItem *> item{new QStandardItem, new QStandardItem, new QStandardItem};
+    const QList<QStandardItem *> item{new QStandardItem, new QStandardItem, new QStandardItem};
     d->model.appendRow(item);
 
     const int rowCount = d->model.rowCount();
